import { Point } from '../rga/Point';
import { OverlayPoint } from './OverlayPoint';
import { MarkerOverlayPoint } from './MarkerOverlayPoint';
import type { Peritext } from '../Peritext';
import type { Stateful } from '../types';
import type { Printable } from 'tree-dump/lib/types';
import type { Slice } from '../slice/types';
/**
 * Overlay is a tree structure that represents all the intersections of slices
 * in the text. It is used to quickly find all the slices that overlap a
 * given point in the text. The overlay is a read-only structure, its state
 * is changed only by calling the `refresh` method, which updates the overlay
 * based on the current state of the text and slices.
 */
export declare class Overlay<T = string> implements Printable, Stateful {
    protected readonly txt: Peritext<T>;
    root: OverlayPoint<T> | undefined;
    constructor(txt: Peritext<T>);
    first(): OverlayPoint<T> | undefined;
    iterator(): () => OverlayPoint<T> | undefined;
    splitIterator(): () => MarkerOverlayPoint | undefined;
    /**
     * Retrieve overlay point or the previous one, measured in spacial dimension.
     */
    getOrNextLower(point: Point<T>): OverlayPoint<T> | undefined;
    find(predicate: (point: OverlayPoint<T>) => boolean): OverlayPoint<T> | undefined;
    hash: number;
    refresh(slicesOnly?: boolean): number;
    readonly slices: Map<Slice<T>, [start: OverlayPoint<T>, end: OverlayPoint<T>]>;
    private refreshSlices;
    private point;
    private mPoint;
    /**
     * Retrieve an existing {@link OverlayPoint} or create a new one, inserted
     * in the tree, sorted by spatial dimension.
     */
    private upsertPoint;
    /**
     * Inserts a point into the tree, sorted by spatial dimension.
     * @param point Point to insert.
     * @returns Returns the existing point if it was already in the tree.
     */
    private insPoint;
    private delPoint;
    private insMarker;
    private insSlice;
    private delSlice;
    toString(tab?: string): string;
}
